===============
Target audience
===============

Who is the target audience of the cwepr package? Is it interesting for me?


EPR spectroscopists aiming at reproducibility
=============================================

The cwepr package addresses EPR spectroscopists working with larger amounts of data (both, measured and calculated) on a daily base. It strives towards automating processing of cw-EPR data as much as possible, relieving the spectroscopist from tedious, monotonous and often enough error-prone manual routine tasks.


Motivation and general ideas
============================

The motivation and general idea behind the cwepr package is to ensure reproducibility and---as much as possible---replicability of data processing, starting from recording data and ending with their final (graphical) representation, e.g., in a peer-reviewed publication. This is achieved by relying on the `ASpecD framework <https://www.aspecd.de/>`_ taking care of mostly automatically creating a gap-less record of each processing step.

Every scientist should be well familiar with the concept of reproducibility and its importance for science in general. If you don't really care about reproducibility, you will probably have hard time using the cwepr package in the way it is developed for. If, however, you do care about reproducibility and are looking for a system that helps you to achieve this goal, the cwepr package may well be interesting for you.

